@@ -28,9 +28,9 @@
 #include <QDialog>
 
 // Konsole
-#include "SessionManager.h"
-#include "Session.h"
-#include "SessionListModel.h"
+#include "session/SessionManager.h"
+#include "session/Session.h"
+#include "session/SessionListModel.h"
 
 namespace Ui {
 class CopyInputDialog;
@@ -58,8 +58,6 @@ public:
      * and cannot be unchecked.
      */
     void setMasterSession(Session *session);
-    /** See setMasterSession() */
-    Session *masterSession() const;
 
     /** Sets the sessions in the list which are checked. */
     void setChosenSessions(const QSet<Session *> &sessions);
@@ -90,50 +88,6 @@ private:
     QPointer<Session> _masterSession;
 };
 
-/**
- * A list of sessions with a checkbox next to each one which allows the
- * user to select a subset of the available sessions to perform
- * some action on them.
- */
-class CheckableSessionModel : public SessionListModel
-{
-    Q_OBJECT
-
-public:
-    explicit CheckableSessionModel(QObject *parent);
-
-    void setCheckColumn(int column);
-    int checkColumn() const;
-
-    /**
-     * Sets whether a session can be checked or un-checked.
-     * Non-checkable items have the Qt::ItemIsEnabled flag unset.
-     */
-    void setCheckable(Session *session, bool checkable);
-
-    /** Sets the list of sessions which are currently checked. */
-    void setCheckedSessions(const QSet<Session *> &sessions);
-    /** Returns the set of checked sessions. */
-    QSet<Session *> checkedSessions() const;
-
-    // reimplemented from QAbstractItemModel
-    Qt::ItemFlags flags(const QModelIndex &index) const override;
-    QVariant data(const QModelIndex &index, int role) const override;
-    bool setData(const QModelIndex &index, const QVariant &value, int role) override;
-
-protected:
-    void sessionRemoved(Session *) override;
-
-private:
-    QSet<Session *> _checkedSessions;
-    QSet<Session *> _fixedSessions;
-    int _checkColumn;
-};
-
-inline int CheckableSessionModel::checkColumn() const
-{
-    return _checkColumn;
-}
 }
 
 #endif // COPYINPUTDIALOG_H
