@@ -43,7 +43,6 @@ class TabbedViewContainer;
 class TerminalDisplay;
 class ViewProperties;
 class ViewSplitter;
-class SessionDisplayConnection;
 
 /**
  * Manages the terminal display widgets in a Konsole window or part.
@@ -177,7 +176,10 @@ public:
     int managerId() const;
 
     /** Returns a list of sessions in this ViewManager */
-    QList<Session *> sessions();
+    QList<Session *> sessions()
+    {
+        return _sessionMap.values();
+    }
 
     /**
      * Returns whether the @p profile has the blur setting enabled
@@ -429,9 +431,7 @@ private:
     QPointer<TabbedViewContainer> _viewContainer;
     QPointer<SessionController> _pluggedController;
 
-    // TODO: This map must be separated into a new class containing the global link map between sessions and displays used by the entire konsole
-    // The solution implemented so far is initial and should be reviewed
-    QVector<SessionDisplayConnection*> _sessionMap;
+    QHash<TerminalDisplay *, Session *> _sessionMap;
 
     KActionCollection *_actionCollection;
 
