@@ -42,6 +42,7 @@ private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
     void testSessions();
+    void testWindows();
 
 // protected slots are not treated as test cases
 protected Q_SLOTS:
@@ -49,6 +50,10 @@ protected Q_SLOTS:
 private:
     QString _interfaceName;
     QProcess *_process = nullptr;
+
+    QString _testProfileName;
+    QString _testProfilePath;
+    QString _testProfileEnv;
 };
 
 }
