@@ -25,8 +25,9 @@
 #include <QFileInfo>
 
 // Konsole
-#include "../Profile.h"
-#include "../ProfileWriter.h"
+#include "../profile/Profile.h"
+#include "../profile/ProfileGroup.h"
+#include "../profile/ProfileWriter.h"
 
 #include <array>
 
