@@ -27,7 +27,7 @@ class SessionManagerTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void init();
     void cleanup();
 
