@@ -21,10 +21,13 @@
 // Own
 #include "TerminalCharacterDecoderTest.h"
 
+// Konsole
+#include "../PlainTextDecoder.h"
+#include "../HTMLDecoder.h"
+
 // Qt
 #include <QTextStream>
 
-
 // KDE
 #include <qtest.h>
 
